import uuid

from gcs_cli.helpers import default_principal_resolver, requires_login
from gcs_cli.parsing import globus_command, role_id_arg
from gcs_cli.prettyprint import FORMAT_TEXT_RECORD, FieldSpec, formatted_print
from gcs_cli.services.gcs import get_client

STANDARD_FIELDS: FieldSpec = [
    ("Role ID", "id"),
    ("Collection ID", "collection"),
    ("Role", "role"),
    ("Principal", default_principal_resolver.field),
]


@globus_command("show", short_help="Show a Collection Role definition.")
@role_id_arg
@requires_login
def role_show(role_id: uuid.UUID) -> None:
    """
    Show a Collection Role definition.
    """
    client = get_client()

    res = client.get_role(role_id)

    # walk the list of all known fields and reduce the rendering to only look
    # for fields which are actually present
    real_fields = []
    for name, key in STANDARD_FIELDS:
        if key in res or not isinstance(key, str):
            real_fields.append((name, key))

    formatted_print(res, text_format=FORMAT_TEXT_RECORD, fields=real_fields)
