import uuid
from typing import Union

import click

from gcs_cli.helpers import record_print_result_message, requires_login
from gcs_cli.parsing import UUIDorUsername, globus_command
from gcs_cli.sdk_client.data import OwnerStringDocument
from gcs_cli.services.auth import get_client as get_auth_client
from gcs_cli.services.gcs import get_client


@globus_command(
    "set-owner-string", short_help="Set the advertised endpoint owner string"
)
@click.argument("OWNER", type=UUIDorUsername())
@requires_login
def endpoint_set_owner_string(owner: Union[str, uuid.UUID]) -> None:
    """
    Update the advertised owner string the endpoint to which you are currently
    logged in

    This command may only be performed by an endpoint owner or administrator, and
    can only set the advertised owner to an identity within the caller's identity
    set which has an endpoint owner or administrator role.
    """
    client = get_client()
    owner_id = None

    if isinstance(owner, uuid.UUID):
        owner_id = str(owner)
    else:
        auth_client = get_auth_client()
        res = auth_client.get_identities(usernames=owner)["identities"]

        if not res:
            res = []
        for identity in res:
            if identity["username"] == owner:
                owner_id = identity["id"]
                break
        if not owner_id:
            click.echo("No such identity {}".format(owner), err=True)
            click.get_current_context().exit(1)

    doc = OwnerStringDocument(identity_id=owner_id)

    res = client.put_endpoint_owner_string(data=doc)
    record_print_result_message(res)
