from typing import List, Tuple

import click

from ..models import MigrationPlan
from .decorators import requires_migration_plan


@click.command("list", help="List sharing state files")
@requires_migration_plan
def sharing_state_list(migration_plan: MigrationPlan) -> None:
    lines: List[Tuple[str, str, str, str]] = []
    titles: Tuple[str, str, str, str] = ("User", "ID", "State File", "Base Path")
    widths: Tuple[int, int, int, int] = (
        len(titles[0]),
        len(titles[1]),
        len(titles[2]),
        len(titles[3]),
    )

    if migration_plan.guest_collections:
        for gc in migration_plan.guest_collections:
            if not gc.disable:
                assert gc.credential is not None
                assert gc.credential.username is not None
                assert gc.id is not None
                assert gc.share_state_file is not None
                assert gc.base_path is not None or gc.host_path is not None
                data: Tuple[str, str, str, str] = (
                    gc.credential.username,
                    gc.id,
                    str(gc.share_state_file),
                    f"{gc.base_path if gc.base_path else gc.host_path}",
                )

                widths = (
                    widths[0] if len(data[0]) < widths[0] else len(data[0]),
                    widths[1] if len(data[1]) < widths[1] else len(data[1]),
                    widths[2] if len(data[2]) < widths[2] else len(data[2]),
                    widths[3] if len(data[3]) < widths[3] else len(data[3]),
                )
                lines.append(data)

        fmt = (
            f"{{0:^{2 + widths[0]}}}"
            f"|{{1:^{2 + widths[1]}}}"
            f"|{{2:^{2 + widths[2]}}}"
            f"|{{3:^{2 + widths[3]}}}"
        )

        click.echo(fmt.format(*titles))
        click.echo(
            fmt.format(
                (widths[0] + 2) * "-",
                (widths[1] + 2) * "-",
                (widths[2] + 2) * "-",
                (widths[3] + 2) * "-",
            )
        )
        for line in lines:
            click.echo(fmt.format(*line))
