from dataclasses import dataclass
from typing import Any, Dict


@dataclass
class BlackPearlMapEntry:
    username: str
    access_id: str
    secret_key: str

    def __eq__(self, other: Any) -> bool:
        if not isinstance(other, BlackPearlMapEntry):
            return NotImplemented
        return self is other or (
            self.username == other.username
            and self.access_id == other.access_id
            and self.secret_key == other.secret_key
        )


class BlackPearlAccessIdFileParser:
    def __init__(self, path: str) -> None:
        self.mapfile_entries: Dict[str, BlackPearlMapEntry] = {}

        self.path = path

        with open(self.path, "r") as f:
            for line in f:
                line = line.split("#", 1)[0]
                line = line.strip()
                if line:
                    values = line.split(maxsplit=2)
                    if len(values) != 3:
                        continue
                    username, access_id, secret_key = values
                    self.mapfile_entries[username] = BlackPearlMapEntry(
                        username, access_id, secret_key
                    )

    def __contains__(self, username: str) -> bool:
        return self.mapfile_entries.get(username) is not None

    def __getitem__(self, username: str) -> BlackPearlMapEntry:
        return self.mapfile_entries[username]
