from typing import Optional


class _HPSSEnv:
    def __init__(self, path: str = None) -> None:
        if path is None:
            path = "/var/hpss/etc/env.conf"

        self.path: str = path
        self.hpss_api_authn_mech: Optional[str] = None
        self.hpss_primary_authn_mech: Optional[str] = None
        self.hpss_primary_authenticator: Optional[str] = None

        with open(path, "r") as f:
            for line in f:
                line = line.split("#", 1)[0].strip()
                if line and "=" in line:
                    k, v = line.split("=", 1)
                    k = k.strip()
                    v = v.strip()

                    if k == "HPSS_API_AUTHN_MECH":
                        self.hpss_api_authn_mech = v
                    elif k == "HPSS_PRIMARY_AUTHN_MECH":
                        self.hpss_primary_authn_mech = v
                    elif k == "HPSS_PRIMARY_AUTHENTICATOR":
                        self.hpss_primary_authenticator = v


class HPSSConfig:
    def __init__(self, path: str = None) -> None:
        if path is None:
            path = "/var/hpss/etc/gridftp_hpss_dsi.conf"

        self.path = path
        self.login_name: str = "hpssftp"
        # Defaults to HPSS_API_AUTHN_MECH or HPSS_PRIMARY_AUTHN_MECH
        self.authentication_mech: Optional[str] = None
        # Defaults to HPSS_PRIMARY_AUTHENTICATOR
        self.authenticator: Optional[str] = None
        self.uda_checksum_support: str = "off"

        with open(path, "r") as f:
            for line in f:
                line = line.split("#", 1)[0].strip()
                if line:
                    k, v = line.split(" ", 1)
                    k = k.strip()
                    v = v.strip()

                    if k == "LoginName":
                        self.login_name = v
                    elif k == "AuthenticationMech":
                        self.authentication_mech = v
                    elif k == "Authenticator":
                        self.authenticator = v
                    elif k == "UDAChecksumSupport":
                        self.uda_checksum_support = v

        if not self.authentication_mech or not self.authenticator:
            try:
                hpss_env = _HPSSEnv()

                if not self.authentication_mech:
                    self.authentication_mech = hpss_env.hpss_api_authn_mech
                    if not self.authentication_mech:
                        self.authentication_mech = hpss_env.hpss_primary_authn_mech
                if not self.authenticator:
                    self.authenticator = hpss_env.hpss_primary_authenticator
            except FileNotFoundError:
                # /var/hpss/etc/env.conf almost always exists but it is not an error if
                # it is missing.
                pass
