class S3Config:
    @staticmethod
    def __parse_bool(value: str) -> bool:
        return value.lower() in ["true", "yes", "on", "1"]

    def __init__(self, path: str = None) -> None:
        if path is None:
            path = "/etc/globus/globus-gridftp-server-s3.conf"

        self.path = path
        self.host_name = "s3.amazonaws.com"
        self.use_https = True
        self.use_virtual_host = False
        self.verify_peer = True
        self.max_retries = 5
        self.retry_delay = 400
        self.s3_map_filename = "$HOME/.globus/s3"

        with open(path, "r") as f:
            for line in f:
                line = line.split("#", 1)[0].strip()
                if line and "=" in line:
                    k, v = line.split("=", 1)
                    k = k.strip()
                    v = v.strip()
                    v = v.strip('"')

                    if k == "host_name":
                        self.host_name = v
                    elif k == "use_https":
                        self.use_https = self.__parse_bool(v)
                    elif k == "use_virtual_host":
                        self.use_virtual_host = self.__parse_bool(v)
                    elif k == "verify_peer":
                        self.verify_peer = self.__parse_bool(v)
                    elif k == "max_retries":
                        self.max_retries = int(v)
                    elif k == "retry_delay":
                        self.retry_delay = int(v)
                    elif k == "s3_map_filename":
                        self.s3_map_filename = v
