"""
Marshmallow schemas and helpers for processing GCS Manager API documents and
storing database state in AWS AppSync.

All of the documents involved in the API include a versioned DATA_TYPE property
which determines which schemas to use when processing a document.
"""

from .api import (
    data_type,
    data_type_schema,
    semantic_version_expression,
    storage_gateway_policy,
    user_credential_policy,
    verify_schema_version,
    version_safe_type_schemas,
)
from .api_v1 import OAuthUserCredentialForm  # noqa: F401
from .connectors import __all__ as connectors_all  # noqa: F401
from .gridftp import GridFTPLogin  # noqa: F401

__all__ = [
    "data_type",
    "data_type_schema",
    "semantic_version_expression",
    "storage_gateway_policy",
    "user_credential_policy",
    "verify_schema_version",
    "version_safe_type_schemas",
]
