# flake8: noqa
"""


The Globus Connect Server Manager API provides interfaces for
configuring a GCS endpoint and managing storage gateways, user
credentials, and collections.

The GCS API follows the REST design model, with resources representing
storage gateways and their policies, user credentials, and collections.

All operations return a variation of the Result data type, defines
the base message and response code, extended with
operation-specific response data.

## Changes

### 1.18.0
* GCS 5.4.60 release
* Add the read-only created_at and last_access properties to the
  collection schema.
* Add new filter query parameter value to GET /api/collections to allow
  filtering collections by created_at or last_access property values.
* Add new API for deleting multiple guest collections in one request.

### 1.17.0
* GCS 5.4.59 release
* Add s3_requester_pays support to the S3 connector.

### 1.16.0
* GCS 5.4.58 release
* Allow users with an administrator role on a mapped collection to
  delete guest collections associated with that collection.
* GET /storage_gateways no longer quietly ignores private_policies

### 1.15.0
* GCS 5.4.57 release
* Add guest_auth_policy_id for collections
* Increase maxLength of user_message to 256
* Clarify visibility of root_path on guest collections
* Add delete_protected for collections

### 1.14.0
* GCS 5.4.55 release
* Add endpoint#1.1.0 document type to support setting GridFTP
  control port to something other than 443

### 1.13.0
* GCS 5.4.51 release
* Add include=all optional query parameter to GET /user_credentials.

### 1.12.0
* GCS 5.4.49 release
* Add admin_managed_credentials property to storage_gateway#1.2.0

### 1.11.0
* GCS 5.4.43 release
* Add API routes for endpoint and collection advertised
  owner_string.
* Add HPSS connector

### 1.10.0
* GCS 5.4.30 release
* Add service_account_key to google_cloud_storage_policies#1.0.0

### 1.9.0
* GCS 5.4.28 release
* Add Azure Blob storage support

### 1.8.0
* GCS 5.4.27 release
* Added disable_anonymous_writes to collection#1.5.0

### 1.7.0
* GCS 5.4.21 release
* Added support for the multi-factor requirement to storage gateways
* Added force_verify to collection#1.4.0
* Add ActiveScale connector

### 1.6.0
* GCS 5.4.18 release
* Add OneDrive connector and related policy documents
* Replace google-cloud-platform-connector module with
  a more correct oauth-credential-api module.
* Add support for user sharing policies

### 1.5.0
* GCS 5.4.15 release
* Add node#1.1.0 document

### 1.4.0
* GCS 5.4.13 release
* Add custom domain APIs: the `/endpoint/domain` and
  `/collections/{collection_id}/domain` route and the
  `custom_domain#1.0.0` document.

### 1.3.0
* GCS 5.4.10 release
* Add POSIX staging connector and related policy documents.
* Add iRODS connector and related policy documents

### 1.2.0
* GCS 5.4.8 release
* Add `sharing_users_allow`, `sharing_users_deny` to the
  Collection document (`collection#1.2.0`)
* Add `sharing_groups_allow`, `sharing_groups_deny` to the
  Posix Collection Policies document (`posix_collection_policies#1.1.0`)

### 1.1.0
* GCS 5.4.5 release
* Add `enable_https`, `user_message`, and `user_message_link` to
  Collection document (`collection#1.1.0`)

### 1.0.0
* GCS 5.4.0 release

## API Reference

"""

from .account import Account
from .batch import Batch
from .authentication_timeout import AuthenticationTimeout
from .collection import (
    Collection,
    collection_configuration_schema,
    collection_policy,
)
from .connector import Connector
from .credential_not_found import CredentialNotFound
from .data_type import (
    data_type,
    data_type_schema,
    FormSchema,
    OneOfSchema,
    PolicySchema,
    Schema,
)
from .domain import (
    DomainDict,
    ManagedDomainDict,
    UnmanagedDomainDict,
    Domain,
)
from .endpoint import Endpoint
from .endpoint_owner import EndpointOwner
from .endpoint_subscription import EndpointSubscription
from .id_not_in_identity_set import IdNotInIdentitySet
from .info import Info
from .invalid_credential import InvalidCredential
from .invalid_input import InvalidInput
from .invalid_user import InvalidUser
from .identity_mapping import (
    IdentityMapping,
)
from .limit_exceeded import LimitExceeded
from .missing_required_role import MissingRequiredRole
from .missing_required_scopes import MissingRequiredScopes
from .node import Node
from .not_from_allowed_domain import NotFromAllowedDomain
from .not_resource_owner import NotResourceOwner
from .owner_string import OwnerString
from .path_restrictions import PathRestrictions, PathRestrictionsDict
from .result import Result
from .resource_conflict import ResourceConflict
from .role import Role
from .sharing_policy import SharingPolicyDumpDict, SharingPolicyLoadDict, SharingPolicy
from .semantic_version import semantic_version_expression
from .schema_version_checker import verify_schema_version, version_safe_type_schemas
from .storage_gateway import StorageGateway, storage_gateway_policy
from .subscription_required import SubscriptionRequired
from .user_credential import UserCredential, user_credential_policy

__all__ = [
    "data_type",
    "data_type_schema",
    "semantic_version_expression",
    "storage_gateway_policy",
    "user_credential_policy",
    "verify_schema_version",
    "version_safe_type_schemas",
]
