import marshmallow as ma

from .semantic_version import semantic_version_expression
from .data_type import data_type, data_type_schema, Schema


@data_type("info#1.0.0")
class Info_1_0_0(Schema):
    """
    This document contains information about the Globus Connect
    Server, including its software and supported API version
    number.
    """

    manager_version = ma.fields.Str(
        validate=[ma.validate.Regexp(semantic_version_expression)],
        description="Globus Connect Server software version",
    )
    api_version = ma.fields.Str(
        validate=[ma.validate.Regexp(semantic_version_expression)],
        description="Semantic version of the Globus Connect Server API",
    )
    client_id = ma.fields.UUID(description="Client id that created the endpoint")
    endpoint_id = ma.fields.UUID(
        description="Transfer endpoint ID managed by this GCS Manager"
    )
    domain_name = ma.fields.String(
        description="Domain name for the GCS Manager service"
    )


Info = data_type_schema.Info
