import marshmallow as ma

from .data_type import data_type, data_type_schema, Schema


class InvalidInputItem(ma.Schema):
    """
    Invalid input item details.
    """

    message = ma.fields.String(
        required=True,
        allow_none=False,
        description="Error message describing the invalid input error",
    )

    _property = ma.fields.String(
        data_key="property",
        attribute="property",
        required=False,
        allow_none=False,
        description="""
        Name of the property whose value contains the error, if known. May
        be unset depending on the error.
        """,
    )


@data_type("invalid_input#1.0.0")
class InvalidInput_1_0_0(Schema):
    """
    Error details when the caller has sent an invalid input document.
    """

    errors = ma.fields.List(
        ma.fields.Nested(InvalidInputItem),
        description="""
        Optional list of input schema violations, such as missing or
        unknown properties, or properties with invalid values.
        """,
    )


InvalidInput = data_type_schema.InvalidInput
