from typing import List, Optional
from typing_extensions import Literal, TypedDict

from ..api import data_type, data_type_schema, Schema

import marshmallow as ma


class OIDCRegistrationDict(TypedDict, total=False):
    DATA_TYPE: Literal["oidc_registration#1.0.0"]
    auth_client_id: Optional[str]
    environment: Optional[str]
    display_name: str
    discovery_url: str
    domain_name: Optional[str]
    domains: Optional[List[str]]
    support_contact: str
    support_email: str
    username_claim: str
    id_claim: str
    oidc_client_id: str
    oidc_client_secret: str


@data_type("oidc_registration#1.0.0", schema_base_name="OIDCRegistration", private=True)
class OIDCRegistration_1_0_0(Schema):
    """
    Marshmallow schema used by the GCS model. This is the data stored in appsync
    and shared between DTNs.
    """

    auth_client_id = ma.fields.String(allow_none=True)
    environment = ma.fields.String(allow_none=True)

    display_name = ma.fields.String(allow_none=True)
    support_contact = ma.fields.String(required=True)
    support_email = ma.fields.Email(required=True)
    discovery_url = ma.fields.String(allow_none=True)
    domain_name = ma.fields.String(allow_none=True)
    domains = ma.fields.List(ma.fields.String(), allow_none=True)
    oidc_client_id = ma.fields.String(allow_none=True)
    oidc_client_secret = ma.fields.String(allow_none=True)
    username_claim = ma.fields.String(allow_none=True)
    id_claim = ma.fields.String(allow_none=True)

    deleted = ma.fields.Boolean()


OIDCRegistration = data_type_schema.OIDCRegistration
