import marshmallow as ma

from ..api import (
    PolicySchema,
    collection_policy,
    data_type_schema,
    storage_gateway_policy,
    user_credential_policy,
)


CEPH_CONNECTOR_ID = "1b6374b0-f6a4-4cf7-a26f-f262d9c6ca72"


@storage_gateway_policy("ceph_storage_policies#1.0.0")
class CephStoragePolicies_1_0_0(PolicySchema):
    """
    Connector-specific storage gateway policies for the Ceph connector
    """

    s3_endpoint = ma.fields.Url(description="URL of the Ceph RADOS Gateway S3 API")
    s3_buckets = ma.fields.List(
        ma.fields.Str,
        description="""
        List of buckets not owned by the collection owner that will be shown in
        the root of collections created at the base of this Storage Gateway.
        """,
    )
    ceph_admin_key_id = ma.fields.Str(
        description="""
        Administrator key id used to authenticate with the ceph admin service
        to obtain user credentials.
        """
    )
    ceph_admin_secret_key = ma.fields.Str(
        description="""
        Administrator secret key used to authenticate with the ceph admin
        service to obtain user credentials.
        """
    )

    private = ["ceph_admin_key_id", "ceph_admin_secret_key"]
    connector_id = CEPH_CONNECTOR_ID


@collection_policy("ceph_collection_policies#1.0.0")
class CephCollectionPolicies_1_0_0(PolicySchema):
    """
    Connector-specific collection policies for the Ceph connector
    """

    connector_id = CEPH_CONNECTOR_ID


@user_credential_policy("ceph_user_credential_policies#1.0.0")
class CephUserCredentialPolicies_1_0_0(PolicySchema):
    """
    Connector-specific user credential policies for the Ceph connector
    """

    connector_id = CEPH_CONNECTOR_ID


CephCollectionPolicies = data_type_schema.CephCollectionPolicies
CephStoragePolicies = data_type_schema.CephStoragePolicies
CephUserCredentialPolicies = data_type_schema.CephUserCredentialPolicies
