import marshmallow as ma

from ..api import (
    PolicySchema,
    collection_policy,
    data_type_schema,
    storage_gateway_policy,
    user_credential_policy,
)
from ..cleanup_none_mixin import CleanupNoneMixin


IRODS_CONNECTOR_ID = "e47b6920-ff57-11ea-8aaa-000c297ab3c2"


class IrodsEnvironment(ma.Schema):
    """
    Variables to set in the iRODS client environment.
    """

    name = ma.fields.String(required=True, description="Environment variable name")
    value = ma.fields.String(required=True, description="Environment variable value")


@storage_gateway_policy("irods_storage_policies#1.0.0")
class IrodsStoragePolicies_1_0_0(PolicySchema, CleanupNoneMixin):
    """
    Connector-specific storage gateway policies for the Irods connector
    """

    irods_environment_file = ma.fields.String(
        required=True,
        description="Path to the irods environment file",
        example="/var/irods/irods_environment.json",
    )
    irods_authentication_file = ma.fields.String(
        description="Path to the irods authentication file",
        example="/var/irods/.irodsA",
    )
    environment = ma.fields.List(
        ma.fields.Nested(IrodsEnvironment()),
        description="Variables to set in the iRODS client environment",
    )
    private = ["irods_environment_file", "irods_authentication_file", "environment"]
    connector_id = IRODS_CONNECTOR_ID


@collection_policy("irods_collection_policies#1.0.0")
class IrodsCollectionPolicies_1_0_0(PolicySchema):
    """
    Connector-specific collection policies for the Irods connector
    """

    connector_id = IRODS_CONNECTOR_ID


@user_credential_policy("irods_user_credential_policies#1.0.0")
class IrodsUserCredentialPolicies_1_0_0(PolicySchema):
    """
    Connector-specific user credential policies for the Irods connector
    """

    connector_id = IRODS_CONNECTOR_ID


IrodsCollectionPolicies = data_type_schema.IrodsCollectionPolicies
IrodsStoragePolicies = data_type_schema.IrodsStoragePolicies
IrodsUserCredentialPolicies = data_type_schema.IrodsUserCredentialPolicies
