import marshmallow as ma

from ..api import (
    collection_policy,
    data_type_schema,
    storage_gateway_policy,
    user_credential_policy,
)
from .posix import (
    PosixStoragePolicies_1_0_0,
    PosixUserCredentialPolicies_1_0_0,
    PosixCollectionPolicies_1_1_0,
)


POSIX_STAGING_CONNECTOR_ID = "052be037-7dda-4d20-b163-3077314dc3e6"


class PosixStagingEnvironment(ma.Schema):
    """
    Variables to set in the environment when executing
    the stage_app.
    """

    name = ma.fields.String(required=True, description="Environment variable name")
    value = ma.fields.String(required=True, description="Environment variable value")


@storage_gateway_policy("posix_staging_storage_policies#1.0.0")
class PosixStagingStoragePolicies_1_0_0(PosixStoragePolicies_1_0_0):
    """
    Connector-specific storage gateway policies for the POSIX Staging connector
    """

    stage_app = ma.fields.String(required=True, description="Path to the stage app")
    environment = ma.fields.List(
        ma.fields.Nested(PosixStagingEnvironment),
        description="Variables to set in the environment when executing the stage_app",
    )

    private = PosixStoragePolicies_1_0_0.private + ["stage_app", "environment"]
    connector_id = POSIX_STAGING_CONNECTOR_ID


@collection_policy("posix_staging_collection_policies#1.0.0")
class PosixStagingCollectionPolicies_1_0_0(PosixCollectionPolicies_1_1_0):
    """
    Connector-specific collection policies for the POSIX Staging connector
    """

    connector_id = POSIX_STAGING_CONNECTOR_ID


@user_credential_policy("posix_staging_user_credential_policies#1.0.0")
class PosixStagingUserCredentialPolicies_1_0_0(PosixUserCredentialPolicies_1_0_0):
    """
    Connector-specific user credential policies for the POSIX Staging connector
    """

    connector_id = POSIX_STAGING_CONNECTOR_ID
    private = PosixUserCredentialPolicies_1_0_0.private + []


PosixStagingCollectionPolicies = data_type_schema.PosixStagingCollectionPolicies
PosixStagingStoragePolicies = data_type_schema.PosixStagingStoragePolicies
PosixStagingUserCredentialPolicies = data_type_schema.PosixStagingUserCredentialPolicies
