import marshmallow as ma
from ..api.data_type import data_type, data_type_schema, Schema


@data_type("gridftp_login#1.0.0", schema_base_name="GridFTPLogin", private=True)
class GridFTPLogin_1_0_0(Schema):
    __doc__ = """
    GridFTP Login Information
    """

    identity_ids = ma.fields.List(
        ma.fields.UUID,
        description="""
        List of linked auth identities that transfer has presented to the
        GridFTP server.
        """,
    )


@data_type("gridftp_login#1.1.0", schema_base_name="GridFTPLogin", private=True)
class GridFTPLogin_1_1_0(GridFTPLogin_1_0_0):
    __doc__ = (
        GridFTPLogin_1_0_0.__doc__
        + """
    Version 1.1.0 adds support for username selection.
    """
    )
    username = ma.fields.String(
        required=False, description="Optional local username to use for this login"
    )


GridFTPLogin = data_type_schema.GridFTPLogin
