from globus_sdk import BaseClient
from globus_sdk.scopes import ScopeBuilder


class DnsClient(BaseClient):
    service_name = "dns"
    base_path = "/v1.0"

    def __init__(self, client_id=None, **kwargs):
        self.client_id = client_id
        super().__init__(**kwargs)

    def create_domain(self, a=None, aaaa=None, cname=None, wildcard=True):
        domain = {"wildcard": wildcard}
        if a is not None:
            domain["a"] = sorted(a)
            assert cname is None
        if aaaa is not None:
            domain["aaaa"] = sorted(aaaa)
            assert cname is None
        if cname is not None:
            domain["cname"] = cname
        return self.post("/domain", data=domain)

    def delete_domain(self, domain):
        return self.delete("/domain/{}".format(domain))

    def update_domain(
        self, domain, a=None, aaaa=None, cname=None, wildcard=True, mode="set"
    ):
        data = {"wildcard": wildcard, "mode": mode}
        if a is not None:
            assert cname is None
            data["a"] = sorted(a)
        if aaaa is not None:
            assert cname is None
            data["aaaa"] = sorted(aaaa)
        if cname is not None:
            assert a is None
            assert aaaa is None
            data["cname"] = cname
        else:
            data["cname"] = None

        path = "/domain/{}".format(domain)
        return self.put(path, data=data)

    def create_txt(self, domain, txt, record_name="_acme-challenge"):
        data = {"txt": txt}
        path = "/domain/{0}/txt/{1}".format(domain, record_name)
        return self.put(path, data=data)


DnsScopes = ScopeBuilder(
    "glob.us",
    known_url_scopes=[
        "manage_dns",
    ],
)
