import click

from globus.manager.version import __version__ as package_version

from gcs_cli.version import __version__ as cli_version
from gcs_cli.commands import main as gcs_cli_main
from gcs_cli.commands.endpoint import endpoint_command
from gcs_cli.commands.node import node_command
from gcs_cli.parsing import globus_group

from .endpoint_setup_interface import endpoint_setup
from .endpoint_cleanup_interface import endpoint_cleanup
from .endpoint_migrate_uuid_interface import endpoint_migrate_uuid
from .endpoint_upgrade_interface import endpoint_upgrade
from .generate_completions import generate_completions_command
from .node_setup_interface import node_setup
from .node_cleanup_interface import node_cleanup
from .node_create_interface import node_create
from .node_set_configuration_interface import node_set_configuration
from .assistant.assistant_interface import assistant_command
from .endpoint_migrate4_interface import migrate4
from .oidc_create_interface import oidc_create
from .oidc_register_interface import oidc_register
from .oidc_delete_interface import oidc_delete
from .oidc_show_interface import oidc_show
from .oidc_update_interface import oidc_update
from .oidc_cleanup_interface import oidc_cleanup
from .reaper_interface import reap
from .audit.audit import audit_command
from .certificate import certificate_command

version_message = "globus-connect-server, package {}, cli {}".format(
    package_version, cli_version
)


def update_version(command_or_group):
    result = click.version_option(
        package_version, message=version_message, hidden=True
    )(command_or_group)

    if isinstance(command_or_group, click.Group):
        for c in command_or_group.commands:
            result.commands[c] = update_version(command_or_group.commands[c])
    return result


endpoint_command.add_command(endpoint_setup)
endpoint_command.add_command(endpoint_cleanup)
endpoint_command.add_command(endpoint_migrate_uuid)
endpoint_command.add_command(migrate4)
endpoint_command.add_command(endpoint_upgrade)
node_command.add_command(node_setup)
node_command.add_command(node_cleanup)
node_command.add_command(node_create)
node_command.add_command(node_set_configuration)
gcs_cli_main.add_command(assistant_command)
gcs_cli_main.add_command(reap)
gcs_cli_main.add_command(audit_command)
gcs_cli_main.add_command(certificate_command)
gcs_cli_main.add_command(generate_completions_command)

main = update_version(gcs_cli_main)


# Add the OIDC installation commands.
@globus_group(name="oidc")
def oidc_command():
    """Manage the OIDC server instance or registration"""


oidc_command.add_command(oidc_create)
oidc_command.add_command(oidc_register)
oidc_command.add_command(oidc_delete)
oidc_command.add_command(oidc_show)
oidc_command.add_command(oidc_update)
oidc_command.add_command(oidc_cleanup)
oidc_command = update_version(oidc_command)

main.add_command(oidc_command)

if __name__ == "__main__":
    main()
