"""
Module to configure an apache server on Red Hat Enterprise Linux >= 6 or
compatible system (such as CentOS or Scientific Linux)
"""
from typing import List
import os

__apache_sites_available_file = "/etc/httpd/conf.d/{name}.conf.gcs"
__apache_sites_enabled_file = "/etc/httpd/conf.d/{name}.conf"

__gcs_created_site = "/var/lib/globus-connect-server/created_site_{name}"
__gcs_enabled_site = "/var/lib/globus-connect-server/enabled_site_{name}"

service = "httpd"
required_modules = ["ssl"]
required_confs: List[str] = []


def site_add(name: str, site_config: str, force=False, enable=False):
    site_available = __apache_sites_available_file.format(name=name)
    created_site_path = __gcs_created_site.format(name=name)
    created_new_site = False

    if not os.path.exists(site_available):
        created_new_site = True

    with open(site_available, "w") as f:
        f.write(site_config)

    if force or created_new_site:
        open(created_site_path, "w").close()

    if enable:
        site_enable(name)


def site_remove(name, force=False):
    site_available = __apache_sites_available_file.format(name=name)
    created_site_path = __gcs_created_site.format(name=name)

    site_disable(name)

    if force or os.path.exists(created_site_path):
        try:
            os.remove(site_available)
        except FileNotFoundError:
            pass
        try:
            os.remove(created_site_path)
        except FileNotFoundError:
            pass


def module_enable(module):
    pass


def module_disable(module):
    pass


def site_enable(name, force=False):
    available_site_path = __apache_sites_available_file.format(name=name)
    enabled_site_path = __apache_sites_enabled_file.format(name=name)
    gcs_enabled_site_path = __gcs_enabled_site.format(name=name)
    enabled_site = False

    if not os.path.exists(enabled_site_path):
        enabled_site = True

    if force and os.path.exists(enabled_site_path):
        try:
            os.remove(enabled_site_path)
        except FileNotFoundError:
            pass

    if not os.path.lexists(enabled_site_path):
        os.symlink(available_site_path, enabled_site_path)

    if enabled_site:
        open(gcs_enabled_site_path, "w").close()


def site_disable(name):
    enabled_site_path = __apache_sites_enabled_file.format(name=name)
    gcs_enabled_site = __gcs_enabled_site.format(name=name)

    if os.path.exists(gcs_enabled_site):
        try:
            os.remove(enabled_site_path)
        except FileNotFoundError:
            pass
        try:
            os.remove(gcs_enabled_site)
        except FileNotFoundError:
            pass


def conf_enable(name, force=False):
    pass


def conf_disable(name):
    pass
